@@ -1,17 +1,13 @@
 package Data::Random::NL;
-
 use warnings;
 use strict;
 
 # ABSTRACT: Tools for generating random Dutch numbers
+our $VERSION = '1.1';
 
-use autodie;
-use feature ();
 use Exporter qw(import);
 use Carp qw(croak);
 
-our $VERSION = '1.0';
-
 our @EXPORT_OK = (
     qw(
         generate_bsn
@@ -37,7 +33,6 @@ sub generate_bsn {
 
     # A BSN cannot start with a 00
     while ($bsn[0] == 0 && $bsn[1] == 0) {
-        $bsn[0] = int(rand(10));
         $bsn[1] = int(rand(10));
     }
 
@@ -141,7 +136,7 @@ Data::Random::NL - Tools for generating random Dutch numbers
 
 =head1 VERSION
 
-version 1.0
+version 1.1
 
 =head1 SYNOPSIS
 
